@@ -148,7 +148,7 @@ class Speaker(caching.base.CachingMixin,models.Model):
         words = WordToken.objects.select_related('WordType','Dialog','Dialog__Speaker')
         words = words.filter(WordType__Label__regex = r'^[^{<]').filter(Dialog__Speaker=self)
         #words = words.exclude(WordType__CVSkel__regex = r'^C*VC*$')
-        words = words.exclude(WordType__CVSkel__regex = r"^*'*$")
+        words = words.exclude(WordType__CVSkel__regex = r"[']")
         words = words.exclude(WordType__Label__in = BAD_WORDS)
         #words = words.filter(WordType__CVSkel='CVC')
         #words = words.filter(WordType__Label__in = GOOD_WORDS)
